@@ -24,13 +24,28 @@ class UpgradeManager:
         self.c = Utils.default_colors(enabled=colors_enabled)
         self.current_version: FiggyVersionDetails = VersionTracker.get_version()
 
-    def download(self, remote_path: str, local_path: str):
-        response = requests.get(remote_path, stream=True)
-        with tqdm.wrapattr(open(local_path, "wb+"), "write",
-                           miniters=1, desc=remote_path.split('/')[-1],
-                           total=int(response.headers.get('content-length', 0))) as fout:
-            for chunk in response.iter_content(chunk_size=1024):
-                fout.write(chunk)
+    def download(self, url: str, local_path: str):
+        print("Downloading file....")
+        with requests.get(url, stream=True) as r:
+            r.raise_for_status()
+            with open(local_path, 'wb') as f:
+                for chunk in r.iter_content(chunk_size=1024):
+                    f.write(chunk)
+
+    def download_with_progress(self, url: str, local_path: str):
+        resp = requests.get(url, stream=True)
+        total = int(resp.headers.get('content-length', 0))
+        with open(local_path, 'wb+') as file, tqdm(
+                desc='Downloading',
+                total=total,
+                unit='iB',
+                miniters=1,
+                unit_scale=True,
+                unit_divisor=1024,
+        ) as bar:
+            for data in resp.iter_content(chunk_size=1024):
+                size = file.write(data)
+                bar.update(size)
 
     def is_symlink(self, install_path: str):
         return os.path.islink(install_path)
@@ -56,11 +71,11 @@ class UpgradeManager:
         old_path = f'{install_path}.OLD'
         zip_path = f"{HOME}/.figgy/figgy.zip"
         install_dir = f'{HOME}/.figgy/installations/{latest_version}/{str(uuid.uuid4())[:4]}'
-        remote_path = f'http://www.figgy.dev/releases/cli/{latest_version}/{platform.lower()}/figgy.zip'
+        url = f'http://www.figgy.dev/releases/cli/{latest_version}/{platform.lower()}/figgy.zip'
         os.makedirs(os.path.dirname(install_dir), exist_ok=True)
         suffix = ".exe" if Utils.is_windows() else ""
         self._cleanup_file(zip_path)
-        self.download(remote_path, zip_path)
+        self.download_with_progress(url, zip_path)
 
         with ZipFile(zip_path, 'r') as zipObj:
             zipObj.extractall(install_dir)
@@ -68,15 +83,15 @@ class UpgradeManager:
         if self._utils.file_exists(old_path):
             os.remove(old_path)
 
-        if self._utils.file_exists(install_path):
-            os.rename(install_path, old_path)
-
         executable_path = f'{install_dir}/figgy/{CLI_NAME}{suffix}'
         st = os.stat(executable_path)
         os.chmod(executable_path, st.st_mode | stat.S_IEXEC)
+
+        if self._utils.file_exists(install_path):
+            os.rename(install_path, old_path)
+
         os.symlink(executable_path, install_path)
 
-        self._cleanup_file(zip_path)
 
     def _get_executable_path(self):
         return
@@ -88,17 +103,11 @@ class UpgradeManager:
             log.error(f"Received error when attempting to cleanup install.")
             pass
 
-
     @property
     def install_path(self) -> Optional[str]:
         """
         Prompts the user to get their local installation path.
         """
-        readline.parse_and_bind("tab: complete")
-        comp = Completer()
-        readline.set_completer_delims(' \t\n')
-        readline.parse_and_bind("tab: complete")
-        readline.set_completer(comp.pathCompleter)
         abs_path = os.path.dirname(sys.executable)
         suffix = ".exe" if self._utils.is_windows() else ""
         binary_path = f'{abs_path}/{CLI_NAME}{suffix}'
