@@ -102,6 +102,10 @@ class Utils:
     def file_exists(path: str):
         return Path(path).is_file()
 
+    @staticmethod
+    def is_symlink(path: str):
+        return os.path.islink(path)
+
     @staticmethod
     def is_set_true(attr: frozenset, args) -> bool:
         attr_name = Utils.clean_attr_name(attr)
